Example Gallery
===============

The following notebooks demonstrate capabilities of CurviRiver.

.. include:: examples-gallery.txt

.. toctree::
    :maxdepth: 1
    :hidden:
    :glob:

    examples/*
